server

package
v3.11.0+incompatible Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 12, 2018 License: Apache-2.0 Imports: 25 Imported by: 0

Documentation

Index

Constants

const (
	AuthLoginCallbackEndpoint = "/auth/callback"
	AuthLoginSuccessEndpoint  = "/"
	AuthLoginErrorEndpoint    = "/error"
)

Variables

This section is empty.

Functions

This section is empty.

Types

type KubeConfigTmpl

type KubeConfigTmpl struct {
	// contains filtered or unexported fields
}

KubeConfigTmpl is a template which can be rendered into kubectl config file ready to talk to a tectonic installation.

func NewKubeConfigTmpl

func NewKubeConfigTmpl(clusterName, clientID, clientSecret, k8sURL, dexURL string, k8sCA, dexCA []byte) *KubeConfigTmpl

NewKubeConfigTmpl takes the necessary arguments required to create a KubeConfigTmpl.

func (*KubeConfigTmpl) Execute

func (k *KubeConfigTmpl) Execute(w io.Writer, idToken, refreshToken string) error

Execute renders a kubectl config file unqiue to an authentication session.

type Server

type Server struct {
	K8sProxyConfig       *proxy.Config
	BaseURL              *url.URL
	LogoutRedirect       *url.URL
	PublicDir            string
	TectonicVersion      string
	TectonicCACertFile   string
	Auther               *auth.Authenticator
	StaticUser           *auth.User
	KubectlClientID      string
	ClusterName          string
	KubeAPIServerURL     string
	DeveloperConsoleURL  string
	DocumentationBaseURL *url.URL
	Branding             string
	GoogleTagManagerID   string
	LoadTestFactor       int
	// Helpers for logging into kubectl and rendering kubeconfigs. These fields
	// may be nil.
	KubectlAuther  *auth.Authenticator
	KubeConfigTmpl *KubeConfigTmpl
	DexClient      api.DexClient
	// A client with the correct TLS setup for communicating with the API server.
	K8sClient             *http.Client
	PrometheusProxyConfig *proxy.Config
}

func (*Server) HTTPHandler

func (s *Server) HTTPHandler() http.Handler

Jump to