Documentation
¶
Index ¶
Constants ¶
const ( AuthLoginCallbackEndpoint = "/auth/callback" AuthLoginSuccessEndpoint = "/" AuthLoginErrorEndpoint = "/error" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KubeConfigTmpl ¶
type KubeConfigTmpl struct {
// contains filtered or unexported fields
}
KubeConfigTmpl is a template which can be rendered into kubectl config file ready to talk to a tectonic installation.
func NewKubeConfigTmpl ¶
func NewKubeConfigTmpl(clusterName, clientID, clientSecret, k8sURL, dexURL string, k8sCA, dexCA []byte) *KubeConfigTmpl
NewKubeConfigTmpl takes the necessary arguments required to create a KubeConfigTmpl.
type Server ¶
type Server struct {
K8sProxyConfig *proxy.Config
BaseURL *url.URL
LogoutRedirect *url.URL
PublicDir string
TectonicVersion string
TectonicCACertFile string
Auther *auth.Authenticator
StaticUser *auth.User
KubectlClientID string
ClusterName string
KubeAPIServerURL string
DeveloperConsoleURL string
DocumentationBaseURL *url.URL
Branding string
GoogleTagManagerID string
LoadTestFactor int
// Helpers for logging into kubectl and rendering kubeconfigs. These fields
// may be nil.
KubectlAuther *auth.Authenticator
KubeConfigTmpl *KubeConfigTmpl
DexClient api.DexClient
// A client with the correct TLS setup for communicating with the API server.
K8sClient *http.Client
PrometheusProxyConfig *proxy.Config
}
func (*Server) HTTPHandler ¶
Click to show internal directories.
Click to hide internal directories.